@@ -163,7 +163,7 @@ def cli_generator(obj):
     Generator(obj["config"], obj["tokens"]).run()
 
 
-@main.command("aggregator", help="Managem CNAMEs of aggregators in QA envs")
+@main.command("aggregator", help="Manage CNAMEs of aggregators in QA envs")
 @click.option("-l", "--list", "show_list", required=False, count=True)
 @click.option("-c", "--change", "change", required=False, count=True)
 @click.pass_obj
