@@ -28,7 +28,7 @@ class Rollback:
         if self._project == "prima":
             stacks_name = [
                 "ecs-task-web-vpc-production",
-                "ecs-task-consumer-vpc-production",
+                "ecs-task-consumer-api-vpc-production",
                 "ecs-task-cron-vpc-production",
                 "batch-job-php-production",
             ]
