@@ -17,7 +17,7 @@ ec2 = boto3.client("ec2", region_name="eu-west-1")
 def update_stack(stack_name, version):
     params = update_template_params(stack_name, version)
     if params:
-        logger.info(f"Effettuo update template cloudformation {stack_name}")
+        logger.info(f"Updating cloudformation template {stack_name}")
         cloudformation.update_stack(
             StackName=stack_name,
             TemplateBody=get_template_from_stack_name(stack_name),
@@ -25,7 +25,7 @@ def update_stack(stack_name, version):
             RoleARN="arn:aws:iam::001575623345:role/rollback-service-role-clo-CloudformationRollbackRo-1BBOKCLXONMYM",
         )
     else:
-        logger.error(f"Nessun parametro trovato sullo stack {stack_name}")
+        logger.error(f"No parameter found on the stack {stack_name}")
         sys.exit(-1)
 
 
@@ -143,7 +143,7 @@ def update_stacks(stacks_name, version):
     for stack_name in stacks_name:
         if not stack_update_completed(stack_name):
             logger.error(
-                f"Errore durante l'update dello stack CloudFormation {stack_name}. Contattare i DevOps"
+                f"Error updating CloudFormation stack {stack_name}. Contact the DevOps team."
             )
             sys.exit(-1)
 
