@@ -140,9 +140,7 @@ class DroneHandler:
                 ["drone", "fmt", "--save", ".drone.yml"], cwd=self._path, check=True
             )
         except (CalledProcessError) as e:
-            logger.error(
-                f"{self._repo}: non sono riuscito a formattare il .drone.yml {e}"
-            )
+            logger.error(f"{self._repo}: unable to format the .drone.yml {e}")
             sys.exit(-1)
 
     def validate(self):
@@ -151,7 +149,7 @@ class DroneHandler:
                 ["drone", "lint", "--trusted", ".drone.yml"], cwd=self._path, check=True
             )
         except (CalledProcessError) as e:
-            logger.error(f"{self._path}: il .drone.yml non è valido {e}")
+            logger.error(f"{self._path}: the .drone.yml is not valid {e}")
             sys.exit(-1)
 
     def sign(self):
@@ -162,5 +160,5 @@ class DroneHandler:
                 check=True,
             )
         except (CalledProcessError) as e:
-            logger.error(f"{self._repo}: non sono riuscito a firmare il .drone.yml {e}")
+            logger.error(f"{self._repo}: unable to sign the .drone.yml {e}")
             sys.exit(-1)
